'use client';

import { useState, useEffect } from 'react';
import axios from 'axios';

interface ApiResponse {
  message: string;
  timestamp: string;
}

export default function TestApi() {
  const [response, setResponse] = useState<ApiResponse | null>(null);
  const [error, setError] = useState<string>('');
  const [loading, setLoading] = useState<boolean>(true);

  useEffect(() => {
    const fetchData = async () => {
      try {
        const apiUrl = process.env.NEXT_PUBLIC_API_URL;
        if (!apiUrl) {
          throw new Error('L\'URL de l\'API n\'est pas configurée');
        }

        const result = await axios.get<ApiResponse>(`${apiUrl}/test`);
        setResponse(result.data);
        setError('');
      } catch (err) {
        setError('Erreur lors de la connexion à l\'API: ' + (err instanceof Error ? err.message : 'Erreur inconnue'));
        setResponse(null);
      } finally {
        setLoading(false);
      }
    };

    fetchData();
  }, []);

  if (loading) {
    return <div className="flex items-center justify-center p-4">Chargement...</div>;
  }

  if (error) {
    return (
      <div className="p-4 bg-red-100 border border-red-400 text-red-700 rounded">
        {error}
      </div>
    );
  }

  return (
    <div className="p-4 bg-white shadow rounded">
      <h2 className="text-xl font-bold mb-4 text-gray-800">Test de Connexion API</h2>
      {response && (
        <div className="space-y-2">
          <p className="text-green-600">{response.message}</p>
          <p className="text-sm text-gray-500">
            Timestamp: {new Date(response.timestamp).toLocaleString()}
          </p>
        </div>
      )}
    </div>
  );
} 