import { create } from 'zustand';
import { persist } from 'zustand/middleware';

// Interface pour l'utilisateur
export interface User {
  id: string;
  email: string;
  artist_name: string;
  user_type: 'artist' | 'venue_owner' | 'partner' | 'admin';
  bio_short?: string;
  bio_long?: string;
  profile_picture_url?: string;
  created_at: string;
  updated_at?: string;
}

// Interface pour le store d'authentification
interface AuthState {
  user: User | null;
  token: string | null;
  isAuthenticated: boolean;
  setUser: (user: User, token: string) => void;
  clearUser: () => void;
}

// Création du store avec persistance
const useAuthStore = create<AuthState>()(
  persist(
    (set) => ({
      user: null,
      token: null,
      isAuthenticated: false,

      // Définir l'utilisateur et le token
      setUser: (user: User, token: string) => set({
        user,
        token,
        isAuthenticated: true
      }),

      // Réinitialiser l'état
      clearUser: () => set({
        user: null,
        token: null,
        isAuthenticated: false
      })
    }),
    {
      name: 'auth-storage', // Nom du stockage dans le localStorage
      partialize: (state) => ({ 
        user: state.user,
        token: state.token,
        isAuthenticated: state.isAuthenticated
      })
    }
  )
);

export default useAuthStore; 